@@ -13,21 +13,21 @@ use Data::Object::Space;
 
 no strict 'refs';
 
-our @EXPORT=('dd');
+our @EXPORT = ('dd');
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 sub import {
-  my $args = [map { /([^=]+)=(.*)/; $ENV{$1} = $2; $1 } @ARGV];
+  my $args = [map { /([^=]+)=(.*)/; $ENV{$1} = $2 if $1; $1 || () } @ARGV];
 
-  new_vars([@$args ? @$args : keys %ENV]);
-  use_vars([@$args ? @$args : keys %ENV]);
+  new_vars([@$args ? @$args : grep /^New_/, keys %ENV]);
+  use_vars([@$args ? @$args : grep /^Use_/, keys %ENV]);
 
   ore->export_to_level(1, @_);
 }
 
 fun new_vars($args) {
-  [map new_vars_pump(new_vars_form($_)), grep /^New_/, @$args]
+  [map new_vars_pump(new_vars_form($_)), @$args]
 }
 
 fun new_vars_args($spec) {
@@ -55,7 +55,7 @@ fun new_vars_pump($conf) {
 }
 
 fun use_vars($args) {
-  [map use_vars_pump(use_vars_form($_)), grep /^Use_/, @$args]
+  [map use_vars_pump(use_vars_form($_)), @$args]
 }
 
 fun use_vars_args($spec) {
@@ -108,14 +108,19 @@ Sugar for Perl 5 one-liners
 
   $ft
 
+  # "File::Temp"
+
 =cut
 
 =head1 DESCRIPTION
 
-This package provides automatic object instantiation based on environment
-variables. This package exists because I was bored and inspired by L<new>.
+This package provides automatic package handling and object instantiation based
+on environment variables. This is not a toy, but it's also not a joke. This
+package exists because I was bored, shut-in due to the COVID-19 epidemic of
+2020, and inspired by L<new> and the ravings of a madman (mst). Though you
+could use this package in a script it's meant to be used from the command-line.
 
-=head2 examples
+=head2 new-example
 
 Simple command-line example using env vars to drive object instantiation:
 
@@ -123,6 +128,8 @@ Simple command-line example using env vars to drive object instantiation:
 
   # "File::Temp"
 
+=head2 use-example
+
 Another simple command-line example using env vars to return a
 L<Data::Object::Space> object which calls C<children> and returns an arrayref
 of L<Data::Object::Space> objects:
@@ -138,6 +145,8 @@ of L<Data::Object::Space> objects:
   #   ...,
   # ]
 
+=head2 arg-example
+
 Here's another simple command-line example using args as env vars with ordered
 variable interpolation:
 
@@ -145,6 +154,17 @@ variable interpolation:
 
   # /var/folders/pc/v4xb_.../T/JtYaKLTTSo
 
+=head2 etc-example
+
+Here's a command-line example using the aforementioned sugar with the
+ever-awesome L<Reply> repl:
+
+  $ New_Path_Tiny='pt; /tmp' reply -More
+
+  0> $pt
+
+  # $res[0] = bless(['/tmp', '/tmp'], 'Path::Tiny')
+
 =cut
 
 =head1 AUTHOR
